@@ -39,7 +39,7 @@ int listIndex (const TQStringList&, const TQString&);
   */
 class KPlayerFileDialog : public KFileDialog
 {
-   Q_OBJECT
+   TQ_OBJECT
 
 public: 
   /** Constructor. Parameters are passed to the KFileDialog constructor. */
@@ -55,7 +55,7 @@ public:
   */
 class KPlayerEngine : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
 
 public:
   KPlayerEngine (TDEActionCollection* ac, TQWidget* parent, const char* name, TDEConfig*);
